#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""PatrowlEnginesUtils init file."""


__title__ = 'patrowl_engine_utils'
__version__ = '0.0.2'
__author__ = 'Nicolas MATTIOCCO'
__license__ = 'AGPLv3'
__copyright__ = 'Copyright (C) 2018 Nicolas Mattiocco - @MaKyOtOx'
